(()=>{"use strict";var e={"./src/workers/indexeddb.worker.ts"(e,t,r){var n=r("../../node_modules/.pnpm/matrix-js-sdk@42.2.0/node_modules/matrix-js-sdk/src/indexeddb-worker.ts");const s=self,o=new n.h(s.postMessage);s.onmessage=o.onMessage}};const t={};function r(n){const s=t[n];if(void 0!==s)return s.exports;const o=t[n]={id:n,exports:{}};return e[n].call(o.exports,o,o.exports,r),o.exports}r.m=e,r.x=()=>{let e=r.O(void 0,[383,2654],()=>r("./src/workers/indexeddb.worker.ts"));return e=r.O(e),e},(()=>{const e=[];r.O=(t,n,s,o)=>{if(n){o=o||0;for(var i=e.length;i>0&&e[i-1][2]>o;i--)e[i]=e[i-1];return void(e[i]=[n,s,o])}let a=1/0;for(i=0;i<e.length;i++){let[n,s,o]=e[i],l=!0;for(var c=0;c<n.length;c++)(!1&o||a>=o)&&Object.keys(r.O).every(e=>r.O[e](n[c]))?n.splice(c--,1):(l=!1,o<a&&(a=o));if(l){e.splice(i--,1);const r=s();void 0!==r&&(t=r)}}return t}})(),r.n=e=>{const t=e&&e.__esModule?()=>e.default:()=>e;return r.d(t,{a:t}),t},r.d=(e,t)=>{if(Array.isArray(t))for(var n=0;n<t.length;){var s=t[n++],o=t[n++];r.o(e,s)?0===o&&n++:0===o?Object.defineProperty(e,s,{enumerable:!0,value:t[n++]}):Object.defineProperty(e,s,{enumerable:!0,get:o})}else for(var s in t)r.o(t,s)&&!r.o(e,s)&&Object.defineProperty(e,s,{enumerable:!0,get:t[s]})},r.f={},r.e=e=>Promise.all(Object.keys(r.f).reduce((t,n)=>(r.f[n](e,t),t),[])),r.u=e=>"bundles/"+r.h()+"/"+e+".js",r.miniCssF=e=>{},r.h=()=>"e5d291aa3e06fa38d249",r.g=function(){if("object"==typeof globalThis)return globalThis;try{return this||new Function("return this")()}catch(e){if("object"==typeof window)return window}}(),r.o=(e,t)=>Object.prototype.hasOwnProperty.call(e,t),r.v=(e,t,n,s)=>{var o=fetch(r.p+"bundles/"+r.h()+"/"+n+".wasm"),i=()=>o.then(e=>e.arrayBuffer()).then(e=>WebAssembly.instantiate(e,s)).then(t=>Object.assign(e,t.instance.exports));return o.then(t=>"function"==typeof WebAssembly.instantiateStreaming?WebAssembly.instantiateStreaming(t,s).then(t=>Object.assign(e,t.instance.exports),e=>{if("application/wasm"!==t.headers.get("Content-Type"))return console.warn("`WebAssembly.instantiateStreaming` failed because your server does not serve wasm with `application/wasm` MIME type. Falling back to `WebAssembly.instantiate` which is slower. Original error:\n",e),i();throw e}):i())},r.cjs=e=>{const t={exports:{}};return e.call(t.exports,t,t.exports),t.exports},(()=>{let e;r.g.importScripts&&(e=r.g.location+"");const t=r.g.document;if(!e&&t&&("SCRIPT"===t.currentScript?.tagName.toUpperCase()&&(e=t.currentScript.src),!e)){const r=t.getElementsByTagName("script");if(r.length){let t=r.length-1;for(;t>-1&&(!e||!/^http(s?):/.test(e));)e=r[t--].src}}if(!e)throw new Error("Automatic publicPath is not supported in this browser");e=e.replace(/^blob:/,"").replace(/#.*$/,"").replace(/\?.*$/,"").replace(/\/[^\/]+$/,"/"),r.p=e+"../../"})(),(()=>{if(void 0!==r){var e=r.u,t=r.e,n={},s={};r.u=function(t){return e(t)+(n.hasOwnProperty(t)?"?"+n[t]:"")},r.e=function(o){return t(o).catch(function(t){var i=s.hasOwnProperty(o)?s[o]:3;if(i<1){var a=e(o);throw t.message="Loading chunk "+o+" failed after 3 retries.\n("+a+")",t.request=a,t}return new Promise(function(e){setTimeout(function(){var t=Date.now();n[o]=t,s[o]=i-1,e(r.e(o))},500)})})}}})(),(()=>{var e={3444:1},t=t=>{let[n,o,i]=t;for(var a in o)r.o(o,a)&&(r.m[a]=o[a]);for(i&&i(r);n.length;)e[n.pop()]=1;s(t)};r.f.i=(t,n)=>{e[t]||importScripts(r.p+r.u(t))};var n=self.webpackChunkelement_web=self.webpackChunkelement_web||[],s=n.push.bind(n);n.forEach(t),n.push=t})(),(()=>{const e=r.x;r.x=()=>Promise.all([r.e(383),r.e(2654)]).then(e)})();r.x()})();
//# sourceMappingURL=indexeddb.worker.js.map