.mx_ErrorView{--width:520px;--cpd-separator-inset:calc(50% - var(--width)/2);--cpd-separator-spacing:var(--cpd-space-8x);background-color:var(--cpd-color-theme-bg);background-image:url(../../themes/element/img/compound/fade-arc-light.c8ae4ed.png);background-repeat:no-repeat;background-size:100%;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--cpd-color-text-primary);font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji,Segoe UI Symbol;height:100%;overflow:auto;padding:var(--cpd-space-20x);text-align:center;width:100%}.mx_ErrorView .mx_ErrorView_logo{display:block;margin:0 auto}.mx_ErrorView .mx_ErrorView_container{margin:0 auto var(--cpd-space-8x);max-width:var(--width)}.mx_ErrorView h1,.mx_ErrorView h2{color:var(--cpd-color-text-primary)}.mx_ErrorView h2{font-size:var(--cpd-font-size-heading-sm);margin:var(--cpd-space-8x) 0}.mx_ErrorView p{color:var(--cpd-color-text-secondary)}.mx_ErrorView .mx_ErrorView_flexContainer{-ms-flex-wrap:wrap;flex-wrap:wrap;margin:0 auto;max-width:-webkit-max-content;max-width:-moz-max-content;max-width:max-content;-webkit-box-pack:space-evenly;-ms-flex-pack:space-evenly;justify-content:space-evenly}.mx_ErrorView .mx_ErrorView_buttons{margin-top:var(--cpd-space-6x)}
/*# sourceMappingURL=error-view.css.map*/