(()=>{(()=>{if("undefined"!=typeof __webpack_require__){var e=__webpack_require__.u,t=__webpack_require__.e,n={},o={};__webpack_require__.u=function(t){return e(t)+(n.hasOwnProperty(t)?"?"+n[t]:"")},__webpack_require__.e=function(i){return t(i).catch(function(t){var r=o.hasOwnProperty(i)?o[i]:3;if(r<1){var a=e(i);throw t.message="Loading chunk "+i+" failed after 3 retries.\n("+a+")",t.request=a,t}return new Promise(function(e){setTimeout(function(){var t=Date.now();n[i]=t,o[i]=r-1,e(__webpack_require__.e(i))},500)})})}}})();let e=!1;window.onmessage=function(t){t.origin===window.location.origin&&t.data.blob&&function(t){const n=t.data;e&&document.body.replaceWith(document.createElement("BODY")),e=!0;const o=document.createElement("span");o.id="img";const i=document.createElement("a");i.id="a",i.rel="noreferrer noopener",i.download=n.download,i.style=n.style,i.style.fontFamily="Arial, Helvetica, Sans-Serif",i.href=window.URL.createObjectURL(n.blob),i.appendChild(o),i.appendChild(document.createTextNode(n.textContent)),n.imgStyle?o.style=n.imgStyle:(o.style.width="20px",o.style.height="20px",o.style.webkitMaskSize="20px",o.style.webkitMaskPosition="center",o.style.webkitMaskRepeat="no-repeat",o.style.display="inline-block",o.style.webkitMaskImage=`url('${n.imgSrc}')`,o.style.backgroundColor=i.style.color);const r=document.body;r.style.margin="0px",r.style.overflow="hidden",r.appendChild(i),t.data.auto&&i.click()}(t)}})();
//# sourceMappingURL=usercontent.js.map