"use strict";(self.webpackChunkelement_web=self.webpackChunkelement_web||[]).push([[6184],{"./src/async-components/views/dialogs/security/RecoveryMethodRemovedDialog.tsx"(e,t,s){s.r(t),s.d(t,{default:()=>p});var n=s("../../node_modules/.pnpm/@babel+runtime@7.29.7/node_modules/@babel/runtime/helpers/esm/defineProperty.js"),o=s("../../node_modules/.pnpm/react@19.2.8/node_modules/react/index.js"),r=s("../../node_modules/.pnpm/@vector-im+compound-design-tokens@10.2.1_@types+react@19.2.18_react@19.2.8/node_modules/@vector-im/compound-design-tokens/assets/web/icons/error.js"),i=s("./src/dispatcher/dispatcher.ts"),c=s("./src/languageHandler.ts"),a=s("./src/dispatcher/actions.ts"),l=s("./src/components/views/dialogs/UserTab.ts"),m=s("./src/components/views/dialogs/BaseDialog.tsx"),d=s("./src/components/views/elements/DialogButtons.tsx");class p extends o.PureComponent{constructor(...e){super(...e),(0,n.A)(this,"onGoToSettingsClick",()=>{this.props.onFinished(),i.A.fire(a.r.ViewUserSettings)}),(0,n.A)(this,"onSetupClick",()=>{this.props.onFinished();const e={action:a.r.ViewUserSettings,initialTabId:l.v.Encryption};i.A.dispatch(e)})}render(){const e=o.createElement("span",{className:"mx_KeyBackupFailedDialog_title"},o.createElement(r.A,null),(0,c._t)("encryption|recovery_method_removed|title"));return o.createElement(m.A,{className:"mx_KeyBackupFailedDialog",onFinished:this.props.onFinished,title:e},o.createElement("div",null,o.createElement("p",null,(0,c._t)("encryption|recovery_method_removed|description_1")),o.createElement("p",null,(0,c._t)("encryption|recovery_method_removed|description_2")),o.createElement("strong",{className:"warning"},(0,c._t)("encryption|recovery_method_removed|warning")),o.createElement(d.A,{primaryButton:(0,c._t)("common|setup_secure_messages"),onPrimaryButtonClick:this.onSetupClick,cancelButton:(0,c._t)("common|go_to_settings"),onCancel:this.onGoToSettingsClick})))}}}}]);
//# sourceMappingURL=6184.js.map